@@ -51,9 +51,10 @@ class TileServer(Server):
     """
     names = ('tiles', 'tms')
     request_parser = staticmethod(tile_request)
-    request_methods = ('map', 'tms_capabilities')
+    request_methods = ('map', 'tms_capabilities, tms_root_resource')
     template_file = 'tms_capabilities.xml'
     layer_template_file = 'tms_tilemap_capabilities.xml'
+    root_resource_template_file = 'tms_root_resource.xml'
 
     def __init__(self, layers, md, max_tile_age=None, use_dimension_layers=False, origin=None):
         Server.__init__(self)
@@ -71,7 +72,14 @@ class TileServer(Server):
         if self.origin and not tile_request.origin:
             tile_request.origin = self.origin
         layer, limit_to = self.layer(tile_request)
-        tile = layer.render(tile_request, use_profiles=tile_request.use_profiles, coverage=limit_to)
+
+        def decorate_img(image):
+            query_extent = (layer.grid.srs.srs_code,
+                layer.tile_bbox(tile_request, use_profiles=tile_request.use_profiles))
+            return self.decorate_img(image, 'tms', [layer.name], tile_request.http.environ, query_extent)
+
+        tile = layer.render(tile_request, use_profiles=tile_request.use_profiles, coverage=limit_to, decorate_img=decorate_img)
+
         tile_format = getattr(tile, 'format', tile_request.format)
         resp = Response(tile.as_buffer(), content_type='image/' + tile_format)
         if tile.cacheable:
@@ -83,8 +91,8 @@ class TileServer(Server):
         return resp
 
     def _internal_layer(self, tile_request):
-        if tile_request.dimensions:
-            name = tile_request.layer + '_' + '_'.join(tile_request.dimensions)
+        if '_layer_spec' in tile_request.dimensions:
+            name = tile_request.layer + '_' + tile_request.dimensions['_layer_spec']
         else:
             name = tile_request.layer
         if name in self.layers:
@@ -96,7 +104,7 @@ class TileServer(Server):
         return None
 
     def _internal_dimension_layer(self, tile_request):
-        key = (tile_request.layer, ) + tile_request.dimensions
+        key = (tile_request.layer, tile_request.dimensions.get('_layer_spec'))
         return self.layers.get(key)
 
     def layer(self, tile_request):
@@ -117,7 +125,7 @@ class TileServer(Server):
                     tile_layer.tile_bbox(request, use_profiles=request.use_profiles))
             else:
                 query_extent = None # for layer capabilities
-            result = request.http.environ['mapproxy.authorize']('tms', [request.layer],
+            result = request.http.environ['mapproxy.authorize']('tms', [tile_layer.name],
                 query_extent=query_extent, environ=request.http.environ)
             if result['authorized'] == 'unauthenticated':
                 raise RequestError('unauthorized', status=401)
@@ -125,7 +133,9 @@ class TileServer(Server):
                 return
             if result['authorized'] == 'partial':
                 if result['layers'].get(tile_layer.name, {}).get('tile', False) == True:
-                    limited_to = result.get('limited_to')
+                    limited_to = result['layers'][tile_layer.name].get('limited_to')
+                    if not limited_to:
+                        limited_to = result.get('limited_to')
                     if limited_to:
                         return load_limited_to(limited_to)
                     else:
@@ -165,6 +175,15 @@ class TileServer(Server):
 
         return Response(result, mimetype='text/xml')
 
+    def tms_root_resource(self, tms_request):
+        """
+        :return: root resource with all available versions of the service
+        :rtype: Response
+        """        
+        service = self._service_md(tms_request)
+        result = self._render_root_resource_template(service)
+        return Response(result, mimetype='text/xml')
+
     def _service_md(self, map_request):
         md = dict(self.md)
         md['url'] = map_request.http.base_url
@@ -178,8 +197,12 @@ class TileServer(Server):
         template = get_template(self.layer_template_file)
         return template.substitute(service=bunch(default='', **service), layer=layer)
 
+    def _render_root_resource_template(self, service):
+        template = get_template(self.root_resource_template_file)
+        return template.substitute(service=bunch(default='', **service))
+
 class TileLayer(object):
-    def __init__(self, name, title, md, tile_manager):
+    def __init__(self, name, title, md, tile_manager, dimensions=None):
         """
         :param md: the layer metadata
         :param tile_manager: the layer tile manager
@@ -188,6 +211,7 @@ class TileLayer(object):
         self.title = title
         self.md = md
         self.tile_manager = tile_manager
+        self.dimensions = dimensions
         self.grid = TileServiceGrid(tile_manager.grid)
         self.extent = map_extent_from_grid(self.grid)
         self._empty_tile = None
@@ -235,14 +259,29 @@ class TileLayer(object):
         if not self._empty_tile:
             img = BlankImageSource(size=self.grid.tile_size,
                 image_opts=ImageOptions(format=format, transparent=True))
-            self._empty_tile = img.as_buffer()
+            self._empty_tile = img.as_buffer().read()
         return ImageResponse(self._empty_tile, format=format, timestamp=time.time())
 
-    def tile_bbox(self, tile_request, use_profiles=False):
+    def tile_bbox(self, tile_request, use_profiles=False, limit=False):
         tile_coord = self._internal_tile_coord(tile_request, use_profiles=use_profiles)
-        return self.grid.tile_bbox(tile_coord)
+        return self.grid.tile_bbox(tile_coord, limit=limit)
 
-    def render(self, tile_request, use_profiles=False, coverage=None):
+    def checked_dimensions(self, tile_request):
+        dimensions = {}
+
+        for dimension, values in self.dimensions.iteritems():
+            value = tile_request.dimensions.get(dimension)
+            if value in values:
+                dimensions[dimension] = value
+            elif not value or value == 'default':
+                dimensions[dimension] = values.default
+            else:
+                raise RequestError('invalid dimension value (%s=%s).'
+                    % (dimension, value), request=tile_request,
+                       code='InvalidParameterValue')
+        return dimensions
+
+    def render(self, tile_request, use_profiles=False, coverage=None, decorate_img=None):
         if tile_request.format != self.format:
             raise RequestError('invalid format (%s). this tile set only supports (%s)'
                                % (tile_request.format, self.format), request=tile_request,
@@ -260,12 +299,20 @@ class TileLayer(object):
             else:
                 return self.empty_response()
 
+        dimensions = self.checked_dimensions(tile_request)
+
         try:
             with self.tile_manager.session():
-                tile = self.tile_manager.load_tile_coord(tile_coord, with_metadata=True)
+                tile = self.tile_manager.load_tile_coord(tile_coord,
+                    dimensions=dimensions, with_metadata=True)
             if tile.source is None:
                 return self.empty_response()
 
+            # Provide the wrapping WSGI app or filter the opportunity to process the
+            # image before it's wrapped up in a response
+            if decorate_img:
+                tile.source = decorate_img(tile.source)
+
             if coverage_intersects:
                 if self.empty_response_as_png:
                     format = 'png'
@@ -276,6 +323,7 @@ class TileLayer(object):
 
                 tile.source = mask_image_source_from_coverage(
                     tile.source, tile_bbox, self.grid.srs, coverage, image_opts)
+
                 return TileResponse(tile, format=format, image_opts=image_opts)
 
             format = None if self._mixed_format else tile_request.format
